@@ -83,6 +83,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::cloud_pubsub;
             use checkout_core::schemars::JsonSchema;
             use checkout_core::dropshot;
+            use checkout_core::serde::{Serialize, Deserialize};
             use checkout_core::dropshot::endpoint;
             use checkout_core::dropshot::RequestContext;
             use checkout_core::dropshot::Path;
@@ -471,7 +472,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             }
 
             // payment related endpoints
-            #[derive(JsonSchema)]
+            #[derive(Serialize, Deserialize, JsonSchema)]
             struct CorrelationIdParam {
                 correlation_id: <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID
             }
